Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3305)

Unified Diff: chrome/browser/ui/views/frame/browser_view_layout.h

Issue 63173016: DevTools: place DevTools WebContents underneath inspected WebContents. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/browser_view_layout.h
diff --git a/chrome/browser/ui/views/frame/browser_view_layout.h b/chrome/browser/ui/views/frame/browser_view_layout.h
index 3fe8a8bf6d8f36dd6bc73f0f3724b920cf618546..7ef0e5084ec1da099b59829e9047025ef25591e4 100644
--- a/chrome/browser/ui/views/frame/browser_view_layout.h
+++ b/chrome/browser/ui/views/frame/browser_view_layout.h
@@ -53,7 +53,6 @@ class BrowserViewLayout : public views::LayoutManager {
TabStrip* tab_strip,
views::View* toolbar,
InfoBarContainerView* infobar_container,
- views::View* contents_split,
ContentsContainer* contents_container,
ImmersiveModeController* immersive_mode_controller);
@@ -102,10 +101,10 @@ class BrowserViewLayout : public views::LayoutManager {
int LayoutBookmarkBar(int top);
int LayoutInfoBar(int top);
// Layout the |contents_split_| view between the coordinates |top| and
// |bottom|. See browser_view.h for details of the relationship between
- // |contents_split_| and other views.
- void LayoutContentsSplitView(int top, int bottom);
+ // |contents_container_| and other views.
+ void LayoutContentsContainerView(int top, int bottom);
// Updates |top_container_|'s bounds. The new bounds depend on the size of
// the bookmark bar and the toolbar.
@@ -144,7 +143,6 @@ class BrowserViewLayout : public views::LayoutManager {
views::View* toolbar_;
BookmarkBarView* bookmark_bar_;
InfoBarContainerView* infobar_container_;
- views::View* contents_split_;
ContentsContainer* contents_container_;
views::View* download_shelf_;
@@ -102,10 +101,10 @@ class BrowserViewLayout : public views::LayoutManager {
int LayoutBookmarkBar(int top);
int LayoutInfoBar(int top);
- // Layout the |contents_split_| view between the coordinates |top| and
+ // Layout the |contents_container_| view between the coordinates |top| and
// |bottom|. See browser_view.h for details of the relationship between

Powered by Google App Engine
This is Rietveld 408576698